@@ -244,6 +244,8 @@ class BaseDBoard(object):
         :param int passwd: *password* to connect to the board
         
         '''
+        if self.dapi.regs.scsr.bits.access.value != DApiAccessLevel.NO.value:
+            self.disconnect()
         self.dapi.cmd.connect(level,passwd) 
         try:
             self.dapi.regs.scsr.bits.access.set(level.value)
@@ -281,7 +283,8 @@ class BaseDBoard(object):
         ''' 
         if refresh:
             self.dapi.readReg(self.regs.par)
-        #self._workspace = self.workspaces.getByPAR(self.regs.par.value)
+        if self._workspace is None:
+            self.onPARChanged(self.regs.par, self.regs.par.value, self.regs.par.value)
         return self._workspace
             
     def isOnStandby(self):
