@@ -382,6 +382,9 @@ class RegBit(BaseRegElement):
     def get(self):
         return (self._parent.value & self._mask) >> self.addr
     
+    def strValue(self):
+        return '{v!s}'.format(v=self.choices[self.value])
+    
     @property
     def mask(self):
         return self._mask  
